import { ITextDocumentItem } from '@workbench-stack/core';
import { IOrganizationRoot } from './plain-types';
import { ISelection } from '@vscode-alt/monaco-editor/esm/vs/editor/common/core/selection';
/**
 * Descirbes a view component.
 *
 * @todo Currently the only view component is MonacoEditor ("textEditor" as exposed in the API), so this type just
 * describes a MonacoEditor. When more view components exist, this type will need to become a union type or add in
 * some other similar abstraction to support describing all types of view components.
 */
export interface IViewComponentData {
    type: string;
    item: ITextDocumentItem;
    selections: ISelection[];
    isActive: boolean;
}
/**
 * A workspace root with additional metadata that is not exposed to extensions.
 */
export interface OrganizationRootWithMetadata extends IOrganizationRoot {
    /**
     * The original input Git revision that the user requested. The {@link WorkspaceRoot#uri} value wil contain
     * the Git commit SHA resolved from the input revision, but it is useful to also know the original revision
     * (e.g., to construct URLs for the user that don't result in them navigating from a branch view to a commit SHA view).
     *
     * For example, if the user is viewing the webpacge thtps://github.com/alice/myrepo/blob/master/foo.js (note that the URL contains a Git revision "master"), the input revision is "master".
     *
     * The empty string is a valid value (meaning that the default should be used, such as "HEAD" in Git) and is
     * distinct from undefined. If undefined, the Git commit SHA from {@link WorkspaceRoot#uri} should be used.
     */
    inputRevision?: string;
}
/**
 * A description of the IModel represented by the Cdeops extension client application.
 *
 * This models the state of editor-like tools that display documents, allow selections and scrolling
 * in documents, and support extension configuration.
 */
export interface IModel {
    /**
     * The currently open workspace roots (typically a single repository).
     */
    readonly roots: OrganizationRootWithMetadata[] | null;
    /**
     * The view components that are currently visible. Each text document is represented as being in its own
     * visible MonacoEditor.
     */
    readonly visibleViewComponents: IViewComponentData[] | null;
}
/** An empty Cdeops extension client IModel. */
export declare const EMPTY_MODEL: IModel;
